<?php

namespace Drupal\Tests\Magento\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the Magento module.
 *
 * @group magento
 */
class ConfigFormTest extends BrowserTestBase {

  /**
   * Modules to install.
   *
   * @var array
   */
  protected static $modules = array('magento');

  /**
   * A simple user.
   *
   * @var \Drupal\user\Entity\User
   */
  private $user;
  
  /**
   * Perform initial setup tasks that run before every test method.
   */
  public function setUp(): void {
    parent::setUp();
    $this->user = $this->drupalCreateUser([
      'access magento config page settings',
    ]);
  }

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

 /**
   * Tests that the Magento config page can be reached.
   */
  public function testMagentoPageExists() {
    // Login.
    $this->drupalLogin($this->user);

    // Generator test:
    $this->drupalGet('admin/config/magento');
     $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Tests the config form.
   */
  public function testConfigForm() {
    // Login.
    $this->drupalLogin($this->user);

    // Access config page.
    $this->drupalGet('admin/config/magento');
     $this->assertSession()->statusCodeEquals(200);
    // Test the form elements exist and have defaults.
    $config = $this->config('magento.settings');
    $this->assertSession()->fieldValueEquals(
      'access_token',
      $config->get('access_token'),
    );
    $this->assertSession()->fieldValueEquals(
      'magento_url',
      $config->get('magento_url'),
    );

    // Test Submit Form

    $this->submitForm([
      'access_token' => 'test_token',
      'magento_url' => 'http://test.com',
    ], 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');
  }

}