<?php

namespace Drupal\Tests\magento\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests module uninstallation.
 *
 * @group magento
 */
class UninstallTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['magento'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Module handler to ensure installed modules.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  public $moduleHandler;

  /**
   * Module installer.
   *
   * @var \Drupal\Core\Extension\ModuleInstallerInterface
   */
  public $moduleInstaller;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->moduleHandler = $this->container->get('module_handler');
    $this->moduleInstaller = $this->container->get('module_installer');
  }

  /**
   * Reloads services used by this test.
   */
  protected function reloadServices() {
    $this->rebuildContainer();
    $this->moduleHandler = $this->container->get('module_handler');
    $this->moduleInstaller = $this->container->get('module_installer');
  }

  /**
   * Tests module uninstallation.
   */
  public function testUninstall() {
    // Confirm that the Magento module has been installed.
    $this->assertTrue($this->moduleHandler->moduleExists('magento'));

    // Uninstall Magento.
    $this->moduleInstaller->uninstall(['magento']);
    $this->assertFalse($this->moduleHandler->moduleExists('magento'));
  }

  /**
   * Tests that the module can be reinstalled.
   */
  public function testReinstall() {
    $this->moduleInstaller->uninstall(['magento']);
    $this->assertTrue($this->moduleInstaller->install(['magento']));
    $this->reloadServices();
    $this->assertTrue($this->moduleHandler->moduleExists('magento'));
  }

}